export { useLocalStorage, useMergeRefs, useUncontrolled, useUniqueId } from '@versini/ui-hooks';
import * as React$1 from 'react';
import React__default from 'react';
import * as react_jsx_runtime from 'react/jsx-runtime';
import { Placement } from '@floating-ui/react';

type SpacingType =
	| undefined
	| string
	| number
	| {
			b?: number;
			l?: number;
			r?: number;
			t?: number;
	  };

/**
 * Custom spacing for a component.
 * @example
 * ```tsx
 * <Button spacing={{ b: 2, l: 1, r: 1, t: 2 }}>Hello World</Button>
 * <Button spacing="2">Hello World</Button>
 * <Button spacing={2}>Hello World</Button>
 * ```
 */
type SpacingProps = {
	spacing?: SpacingType;
};

declare const Anchor: React__default.ForwardRefExoticComponent<{
    children?: React__default.ReactNode;
    link?: string | undefined;
    maxLabelLength?: number | undefined;
    noTruncate?: boolean | undefined;
} & {
    children: React__default.ReactNode;
    disabled?: boolean | undefined;
    onClick?: React__default.MouseEventHandler<HTMLButtonElement> | undefined;
} & {
    className?: string | undefined;
    focus?: "dark" | "light" | undefined;
    fullWidth?: boolean | undefined;
    kind?: "dark" | "light" | undefined;
    noBorder?: boolean | undefined;
    raw?: boolean | undefined;
    size?: "small" | "medium" | "large" | undefined;
    slim?: boolean | undefined;
} & SpacingProps & React__default.ButtonHTMLAttributes<HTMLButtonElement> & React__default.AnchorHTMLAttributes<HTMLAnchorElement> & React__default.RefAttributes<HTMLAnchorElement>>;

type BubbleProps = {
	/**
	 * The children to render.
	 */
	children: React.ReactNode;
	/**
	 * CSS class(es) to add to the main component wrapper.
	 */
	className?: string;
	/**
	 * Whether or not to show a "copy/paste" icon next to the Bubble.
	 */
	copyToClipboard?: boolean | string | ((text: any) => void);
	/**
	 * Object depicting the extra rows for the Bubble.
	 * @example
	 * ```tsx
	 * <Bubble
	 * 	footer={{
	 * 		"Sent": "12:00 PM",
	 * 		"Delivered": "12:01 PM",
	 * 		"Read": "12:02 PM",
	 * 	}}
	 * >Hello World</Bubble>
	 * ```
	 */
	footer?: {
		[key: string]: string | number | undefined | null;
	};
	/**
	 * The type of Bubble. This will change the color of the Bubble
	 * as well as the chevron location.
	 */
	kind?: "left" | "right";
	/**
	 * Same as "footer" but accepts raw JSX.
	 */
	rawFooter?: React.ReactNode;
} & SpacingProps;

declare const Bubble: ({ children, kind, className, footer, rawFooter, copyToClipboard, spacing, }: BubbleProps) => react_jsx_runtime.JSX.Element;

declare const Button: React__default.ForwardRefExoticComponent<{
    children: React__default.ReactNode;
    disabled?: boolean | undefined;
    onClick?: React__default.MouseEventHandler<HTMLButtonElement> | undefined;
} & {
    className?: string | undefined;
    focus?: "dark" | "light" | undefined;
    fullWidth?: boolean | undefined;
    kind?: "dark" | "light" | undefined;
    noBorder?: boolean | undefined;
    raw?: boolean | undefined;
    size?: "small" | "medium" | "large" | undefined;
    slim?: boolean | undefined;
} & SpacingProps & React__default.ButtonHTMLAttributes<HTMLButtonElement> & React__default.RefAttributes<HTMLButtonElement>>;

declare const ButtonIcon: React__default.ForwardRefExoticComponent<{
    children: React__default.ReactNode;
    label?: string | undefined;
    labelRight?: string | undefined;
} & {
    className?: string | undefined;
    focus?: "dark" | "light" | undefined;
    fullWidth?: boolean | undefined;
    kind?: "dark" | "light" | undefined;
    noBorder?: boolean | undefined;
    raw?: boolean | undefined;
    size?: "small" | "medium" | "large" | undefined;
    slim?: boolean | undefined;
} & SpacingProps & React__default.ButtonHTMLAttributes<HTMLButtonElement> & React__default.RefAttributes<HTMLButtonElement>>;

declare const ButtonLink: React__default.ForwardRefExoticComponent<{
    children?: React__default.ReactNode;
    link?: string | undefined;
    maxLabelLength?: number | undefined;
    noTruncate?: boolean | undefined;
} & {
    children: React__default.ReactNode;
    disabled?: boolean | undefined;
    onClick?: React__default.MouseEventHandler<HTMLButtonElement> | undefined;
} & {
    className?: string | undefined;
    focus?: "dark" | "light" | undefined;
    fullWidth?: boolean | undefined;
    kind?: "dark" | "light" | undefined;
    noBorder?: boolean | undefined;
    raw?: boolean | undefined;
    size?: "small" | "medium" | "large" | undefined;
    slim?: boolean | undefined;
} & SpacingProps & React__default.ButtonHTMLAttributes<HTMLButtonElement> & React__default.AnchorHTMLAttributes<HTMLAnchorElement> & React__default.RefAttributes<HTMLAnchorElement>>;

type CardProps = {
	/**
	 * The children to render.
	 */
	children: React.ReactNode;

	/**
	 * If the header prop is not provided, the Card must be
	 * described via aria-labelledby.
	 */
	"aria-labelledby"?: string;
	/**
	 * CSS class(es) to add to the main component wrapper.
	 */
	className?: string;
	/**
	 * The content to render in the footer.
	 */
	footer?: React.ReactNode;
	/**
	 * CSS class(es) to add to the footer.
	 */
	footerClassName?: string;
	/**
	 * The content to render in the header.
	 */
	header?: React.ReactNode;
	/**
	 * CSS class(es) to add to the header.
	 */
	headerClassName?: string;
	/**
	 * Whether or not to render the Card with a border.
	 * @default false
	 */
	noBackground?: boolean;
} & SpacingProps;

declare const Card: ({ header, headerClassName, footer, footerClassName, children, noBackground, className, "aria-labelledby": ariaLabelledby, spacing, ...otherProps }: CardProps) => react_jsx_runtime.JSX.Element;

type FlexgridProps = {
	/**
	 * Children of the Flexgrid (FlexgridItem(s) or any other nodes).
	 */
	children: React.ReactNode;

	/**
	 * Equivalent to "justify-content" in flexbox, this prop defines
	 * the alignment along the main axis (horizontal).
	 */
	alignHorizontal?:
		| "normal"
		| "flex-start"
		| "center"
		| "flex-end"
		| "space-between"
		| "space-around"
		| "space-evenly";

	/**
	 * Equivalent to "align-items" in flexbox, this prop defines
	 * the alignment along the cross axis (vertical).
	 */
	alignVertical?:
		| "normal"
		| "flex-start"
		| "center"
		| "flex-end"
		| "stretch"
		| "baseline";

	/**
	 * The class name of the Flexgrid.
	 * It follows the [CSS class name property](https://developer.mozilla.org/en-US/docs/Web/CSS/class).
	 */
	className?: string;

	/**
	 * Width of the gutters between the columns.
	 * See the “Customization -> Spacing” section for
	 * more information about this unit.
	 */
	columnGap?: number;

	/**
	 * Equivalent to "flex-direction" in flexbox, this prop
	 * establishes the main-axis, thus defining the direction
	 * flex items are placed in the flex container. Flexbox is
	 * (aside from optional wrapping) a single-direction layout
	 * concept. Think of flex items as primarily laying out
	 * either in horizontal rows or vertical columns.
	 */
	direction?: "row" | "row-reverse" | "column" | "column-reverse";

	/**
	 * The height of the Flexgrid.
	 * It follows the [CSS height property](https://developer.mozilla.org/en-US/docs/Web/CSS/height).
	 */
	height?: string;

	/**
	 * Width of the gutters between the rows.
	 * See the “Customization -> Spacing” section for
	 * more information about this unit.
	 */
	rowGap?: number;

	/**
	 * The width of the Flexgrid.
	 * It follows the [CSS width property](https://developer.mozilla.org/en-US/docs/Web/CSS/width).
	 */
	width?: string;
};

type FlexgridItemProps = {
	/** Children of the FlexgridItem. */
	children?: React.ReactNode;

	/** Classname to apply to the FlexgridItem. */
	className?: string;

	/** The item will span across the provided number of grid tracks. */
	span?: number | "auto";
};

declare const Flexgrid: ({ children, className, columnGap, rowGap, height, width, direction, alignHorizontal, alignVertical, ...otherProps }: FlexgridProps) => react_jsx_runtime.JSX.Element;

/**
 * FlexgridItem is a child of Flexgrid. It is used to define the width of a
 * column in a Flexgrid. It can be used to span across multiple columns in a
 * Flexgrid by providing a number of columns or "auto" value to the `span` prop.
 */
declare const FlexgridItem: ({ children, className, span, ...otherProps }: FlexgridItemProps) => react_jsx_runtime.JSX.Element;

type FooterProps = {
	/**
	 * CSS class(es) to add to the main component wrapper.
	 */
	className?: string;
	/**
	 * The type of Footer. This will change the color of the Footer.
	 */
	kind?: "dark" | "light";
	/**
	 * Whether or not to render the Footer with paddings.
	 * @default false
	 */
	noPaddings?: boolean;
	/**
	 * The content to render in the first row.
	 */
	row1?: React.ReactNode;
	/**
	 * The content to render in the second row.
	 */
	row2?: React.ReactNode;
} & SpacingProps;

declare const Footer: ({ className, kind, row1, row2, noPaddings, spacing, }: FooterProps) => react_jsx_runtime.JSX.Element;

interface IconsProps
	extends Omit<React.SVGAttributes<SVGElement>, "spacing">,
		SpacingProps {
	/**
	 * Whether or not the icon is decorative only (visual but not
	 * announced to assistive technologies).
	 * @default false
	 */
	decorative?: boolean;
	/**
	 * Whether or not to render the icon in a single color
	 * @default false
	 */
	monotone?: boolean;
	/**
	 * The title to use for the icon. Each icon has a default title,
	 * but it can be overridden with this prop.
	 */
	title?: string;
}

declare const IconBack: ({ className, viewBox, spacing, title, monotone, ...rest }: IconsProps) => react_jsx_runtime.JSX.Element;

declare const IconChart: ({ className, viewBox, spacing, title, monotone, ...rest }: IconsProps) => react_jsx_runtime.JSX.Element;

declare const IconClose: ({ className, viewBox, spacing, title, monotone, ...rest }: IconsProps) => react_jsx_runtime.JSX.Element;

declare const IconCopied: ({ className, viewBox, spacing, title, monotone, ...rest }: IconsProps) => react_jsx_runtime.JSX.Element;

declare const IconCopy: ({ className, viewBox, spacing, title, monotone, ...rest }: IconsProps) => react_jsx_runtime.JSX.Element;

declare const IconDelete: ({ className, viewBox, spacing, title, monotone, ...rest }: IconsProps) => react_jsx_runtime.JSX.Element;

declare const IconDog: ({ className, viewBox, spacing, ...rest }: IconsProps) => react_jsx_runtime.JSX.Element;

declare const IconEdit: ({ className, viewBox, spacing, title, monotone, ...rest }: IconsProps) => react_jsx_runtime.JSX.Element;

declare const IconHide: ({ className, viewBox, spacing, title, monotone, ...rest }: IconsProps) => react_jsx_runtime.JSX.Element;

declare const IconHistory: ({ className, viewBox, spacing, title, monotone, ...rest }: IconsProps) => react_jsx_runtime.JSX.Element;

declare const IconInfo: ({ className, viewBox, spacing, title, monotone, ...rest }: IconsProps) => react_jsx_runtime.JSX.Element;

declare const IconProfile: ({ className, viewBox, spacing, title, monotone, ...rest }: IconsProps) => react_jsx_runtime.JSX.Element;

declare const IconRestore: ({ className, viewBox, spacing, title, monotone, ...rest }: IconsProps) => react_jsx_runtime.JSX.Element;

declare const IconSettings: ({ className, viewBox, spacing, title, monotone, ...rest }: IconsProps) => react_jsx_runtime.JSX.Element;

declare const IconShow: ({ className, viewBox, spacing, title, monotone, ...rest }: IconsProps) => react_jsx_runtime.JSX.Element;

declare const IconUser: ({ className, viewBox, spacing, title, monotone, ...rest }: IconsProps) => react_jsx_runtime.JSX.Element;

type MainProps = {
	/**
	 * The children to render.
	 */
	children: React.ReactNode;
	/**
	 * CSS class(es) to add to the main component wrapper.
	 */
	className?: string;
	/**
	 * Whether or not to render the Main component with no styles.
	 * @default false
	 */
	raw?: boolean;
} & SpacingProps;

declare const Main: ({ children, className, raw, spacing, }: MainProps) => react_jsx_runtime.JSX.Element;

interface MenuProps extends SpacingProps {
	/**
	 * The children to render.
	 */
	children?: React.ReactNode;
	/**
	 * The default location of the popup.
	 * @default "bottom-start"
	 */
	defaultPlacement?: Placement;
	/**
	 * A React component of type Icon to be placed on the left of the label.
	 */
	icon?: React.ReactNode;
	/**
	 * The label to use for the menu button.
	 */
	label?: string;
	/**
	 * Callback fired when the component is opened or closed.
	 * @param open whether or not the menu is open
	 */
	onOpenChange?: (open: boolean) => void;
}

interface MenuItemProps {
	/**
	 * The label to use for the menu item.
	 */
	label: string;
	/**
	 * Whether or not the menu item is disabled.
	 * @default false
	 */
	disabled?: boolean;
	/**
	 * A React component of type Icon to be placed on the left of the label.
	 */
	icon?: React.ReactNode;
}

type MenuSeparatorProps = React.HTMLAttributes<HTMLDivElement>;

declare const Menu: React$1.ForwardRefExoticComponent<Omit<MenuProps & React$1.HTMLProps<HTMLButtonElement>, "ref"> & React$1.RefAttributes<HTMLButtonElement>>;

declare const MenuItem: React$1.ForwardRefExoticComponent<MenuItemProps & React$1.ButtonHTMLAttributes<HTMLButtonElement> & React$1.RefAttributes<HTMLButtonElement>>;
declare const MenuSeparator: ({ className, ...props }: MenuSeparatorProps) => react_jsx_runtime.JSX.Element;

declare const TYPE_PANEL = "panel";
declare const TYPE_MESSAGEBOX = "messagebox";

type PanelProps = {
	/**
	 * The children to render.
	 */
	children: React.ReactNode;
	/**
	 * Callback fired when the component is opened or closed.
	 * @param open whether or not the menu is open
	 */
	onOpenChange: (open: boolean) => void;
	/**
	 * Whether or not to open the component..
	 * @default false
	 */
	open: boolean;
	/**
	 * The title to use for the panel.
	 */
	title: string;
	/**
	 * The type of Panel border.
	 */
	borderKind?: "dark" | "light";
	/**
	 * The content to render in the footer.
	 */
	footer?: React.ReactNode;
	/**
	 * The type of Panel. This will change the layout of the Panel.
	 */
	kind?: typeof TYPE_PANEL | typeof TYPE_MESSAGEBOX;
};

declare const Panel: ({ open, onOpenChange, title, children, footer, borderKind, kind, }: PanelProps) => react_jsx_runtime.JSX.Element;

type SpinnerProps = {
	/**
	 * The kind of spinner to render. This will change the color of the spinner.
	 */
	kind?: "dark" | "light";
	/**
	 * A ref to the spinner element.
	 */
	spinnerRef?: React.RefObject<HTMLDivElement>;
	/**
	 * The type of spinner to render. This will change the layout of the spinner.
	 */
	type?: "circle" | "dots";
} & SpacingProps;

declare const Spinner: ({ spinnerRef, kind, type, spacing, }: SpinnerProps) => react_jsx_runtime.JSX.Element;

type TableProps = {
	/**
	 * This attribute defines the caption (or title) of a table.
	 */
	caption?: React__default.ReactNode;
	/**
	 * The kind of table. It defines the color of the table.
	 */
	kind?: "dark" | "light";
	/**
	 * The max height of the table. It follows the CSS max-height property.
	 * Note: It is required to configure 'maxHeight' prop for the prop
	 * 'stickyHeader' to work.
	 */
	maxHeight?: string;
	/**
	 * If true, the table header will be sticky.
	 * Note: It is required to configure 'maxHeight' prop for the prop
	 * 'stickyHeader' to work.
	 */
	stickyHeader?: boolean;
	/**
	 * This attribute defines an alternative text that summarizes
	 * the content of the table. It is not visible but will be
	 * read out loud by screen readers to represent the table.
	 */
	summary?: string;
} & SpacingProps &
	React__default.HTMLAttributes<HTMLTableElement>;

type TableRowProps = React__default.HTMLAttributes<HTMLTableRowElement>;
type TableBodyProps = React__default.HTMLAttributes<HTMLTableSectionElement>;
type TableHeadProps = React__default.HTMLAttributes<HTMLTableSectionElement>;

type TableCellProps = {
	/**
	 * The type of cell.
	 * @default "td"
	 */
	component?: "td" | "th";
} & React__default.ThHTMLAttributes<HTMLTableCellElement> &
	React__default.TdHTMLAttributes<HTMLTableCellElement>;

declare const Table: ({ children, kind, caption, summary, className, maxHeight, stickyHeader, spacing, ...otherProps }: TableProps) => react_jsx_runtime.JSX.Element;
declare const TableHead: ({ children, className, ...otherProps }: TableHeadProps) => react_jsx_runtime.JSX.Element;
declare const TableBody: ({ children, ...otherProps }: TableBodyProps) => react_jsx_runtime.JSX.Element;
declare const TableRow: ({ children, className, ...otherProps }: TableRowProps) => react_jsx_runtime.JSX.Element;
declare const TableCell: ({ children, component, className, ...otherProps }: TableCellProps) => react_jsx_runtime.JSX.Element;

declare const TextArea: React__default.ForwardRefExoticComponent<{
    label: string;
    name: string;
    borderKind?: "dark" | "light" | undefined;
    error?: boolean | undefined;
    errorKind?: "dark" | "light" | undefined;
    focusKind?: "dark" | "light" | undefined;
    helperText?: string | undefined;
    helperTextOnFocus?: boolean | undefined;
    labelId?: string | undefined;
    noBorder?: boolean | undefined;
    raw?: boolean | undefined;
    rightElement?: React__default.ReactElement<any, string | React__default.JSXElementConstructor<any>> | undefined;
    textAreaClassName?: string | undefined;
} & SpacingProps & React__default.TextareaHTMLAttributes<HTMLTextAreaElement> & React__default.RefAttributes<HTMLTextAreaElement>>;

declare const TextInput: React__default.ForwardRefExoticComponent<{
    rightElement?: React__default.ReactElement<any, string | React__default.JSXElementConstructor<any>> | undefined;
} & {
    label: string;
    name: string;
    borderKind?: "dark" | "light" | undefined;
    error?: boolean | undefined;
    errorKind?: "dark" | "light" | undefined;
    focusKind?: "dark" | "light" | undefined;
    helperText?: string | undefined;
    inputClassName?: string | undefined;
    labelId?: string | undefined;
    noBorder?: boolean | undefined;
    raw?: boolean | undefined;
} & SpacingProps & React__default.InputHTMLAttributes<HTMLInputElement> & React__default.RefAttributes<HTMLInputElement>>;

declare const TextInputMask: React__default.ForwardRefExoticComponent<{
    onMaskChange?: (({ e, masked, }: {
        e: React__default.SyntheticEvent<Element, Event>;
        masked: boolean;
    }) => void) | undefined;
    onTextInputMaskBlur?: (() => void) | undefined;
} & {
    label: string;
    name: string;
    borderKind?: "dark" | "light" | undefined;
    error?: boolean | undefined;
    errorKind?: "dark" | "light" | undefined;
    focusKind?: "dark" | "light" | undefined;
    helperText?: string | undefined;
    inputClassName?: string | undefined;
    labelId?: string | undefined;
    noBorder?: boolean | undefined;
    raw?: boolean | undefined;
} & SpacingProps & React__default.InputHTMLAttributes<HTMLInputElement> & React__default.RefAttributes<HTMLInputElement>>;

type ThemeProviderProps = {
	/**
	 * The children to render.
	 */
	children: React.ReactNode;
	/**
	 * An object specifying custom properties impacting the base theme.
	 * Not all custom properties need to be specified.
	 * @example
	 * ```tsx
	 * // this will change the color of the button to red.
	 * <ThemeProvider customTheme={{ '--av-action-dark': 'red' }}>
	 *  <Button kind="dark">Click me</Button>
	 * </ThemeProvider>
	 * ```
	 */
	customTheme?: Record<string, string>;
	/**
	 * Whether to apply the theme globally or not.
	 * @default false
	 */
	global?: boolean;
};

declare const ThemeProvider: ({ customTheme, children, global, }: ThemeProviderProps) => string | number | boolean | Iterable<React$1.ReactNode> | react_jsx_runtime.JSX.Element | null | undefined;

type ToggleProps = {
	checked: boolean;
	/**
	 * The label to use for the component.
	 */
	label: string;
	/**
	 * The name to use for the component.
	 */
	name: string;
	/**
	 * Callback fired when the component is activated.
	 * @param checked whether or not the component is checked
	 */
	onChange: (checked: boolean) => void;

	/**
	 * The type of Toggle. This will change the color of the Toggle.
	 */
	kind?: "dark" | "light";
	/**
	 * Whether or not to render the label.
	 * @default false
	 */
	labelHidden?: boolean;
} & SpacingProps;

declare const Toggle: ({ checked, onChange, label, labelHidden, name, kind, spacing, }: ToggleProps) => react_jsx_runtime.JSX.Element;

export { Anchor, Bubble, Button, ButtonIcon, ButtonLink, Card, Flexgrid, FlexgridItem, Footer, IconBack, IconChart, IconClose, IconCopied, IconCopy, IconDelete, IconDog, IconEdit, IconHide, IconHistory, IconInfo, IconProfile, IconRestore, IconSettings, IconShow, IconUser, Main, Menu, MenuItem, MenuSeparator, Panel, Spinner, Table, TableBody, TableCell, TableHead, TableRow, TextArea, TextInput, TextInputMask, ThemeProvider, Toggle };
